function [out] =covinfdiscrete(x,y)
% [out] =covariateinf(x,y,H) returns covariate information matrix when the
% response varialbe is discrete based on the paper by Lindsay and Yao
% "Fisher Discrimination Matrix and Dimension Reduction".
%  Each row of x and y represent an observation.

n=length(y);
infx=fisherinf(x);
infxy=0;uy=unique(y);
for j=1:length(uy)
    x1=x(y==uy(j),:);w=length(x1)/n;
    infxy=infxy+w*fisherinf(x1); 
end

covxinf=infxy-infx;
[sv,sd]=eig(covxinf*cov(x)); 
temp=diag(sd);[a,b]=sort(-temp);sd=temp(b);sv=sv(:,b);

out.direction=sv;
out.eigenvalue=sd;
out.covariateinf=covxinf;
out.infxy=infxy;out.infx=infx;



function [out]=fisherinf(x,H)
%[rootvf2,estinf] = wna(x,H) returns the squre root of covariance matrix of
%density square of x and the fisher informatino for f2
%regular bandwidth
s=size(x);N=s(1);d=s(2);
if exist('H')==0
    if d>N/2 
        H=diag(std(x));
    else
        H=cov(x)^(1/2);
    end
    H=H*(4/(d+2)/N)^(1/(d+4));
end
H2=H*H;invH2=inv(H2);
u0=0;u1=zeros(d);u2=zeros(d);u3=zeros(1,d);

for i=1:(N-1);
    for j=(i+1):N;
        %a=mvnpdf(x(i,:),x(j,:),2*H2);
        temp=x(i,:)-x(j,:);a=exp(-0.25*temp*invH2*temp');
        u0=u0+a*2;
        u1=u1+2*a*(1/2*invH2-invH2*((x(i,:)-x(j,:))'*(x(i,:)-x(j,:)))*invH2/4);
    end
   temp=x(i,:)-x(i,:);a=exp(-0.25*temp*invH2*temp');
   u0=u0+a; u1=u1+a*(1/2*invH2);
end
temp=x(N,:)-x(N,:);a=exp(-0.25*temp*invH2*temp');
u0=u0+a;u1=u1+a*(1/2*invH2);
u0=u0/N^2;u1=u1/N^2;
out=u1/u0; %The fisher informatino for density square transformation f2




